@@ -56,7 +56,7 @@ def execute_command_with_sudo_retry(host, command_kwargs, execute_command):
 
     if return_code != 0 and combined_output:
         last_line = combined_output[-1][1]
-        if last_line == 'sudo: a password is required':
+        if last_line.strip() == 'sudo: a password is required':
             command_kwargs['use_sudo_password'] = True  # ask for the password
             return_code, combined_output = execute_command()
 
@@ -275,7 +275,7 @@ def make_unix_command(
 
     if env:
         env_string = ' '.join([
-            '{0}={1}'.format(key, value)
+            '"{0}={1}"'.format(key, value)
             for key, value in six.iteritems(env)
         ])
         command = StringCommand('export', env_string, '&&', command)
