@@ -20,12 +20,27 @@ SYSTEMD_UNIT_NAME_REGEX = (
 )
 
 
+def _make_systemctl_cmd(user_mode=False, machine=None, user_name=None):
+    # base command for normal and user mode
+    systemctl_cmd = 'systemctl --user' if user_mode else 'systemctl'
+
+    # add user and machine flag if given in args
+    if machine is not None:
+        if user_name is not None:
+            machine_opt = '--machine={1}@{0}'.format(machine, user_name)
+        else:
+            machine_opt = '--machine={0}'.format(machine)
+
+        systemctl_cmd = '{0} {1}'.format(systemctl_cmd, machine_opt)
+
+    return systemctl_cmd
+
+
 class SystemdStatus(FactBase):
     '''
     Returns a dict of name -> status for systemd managed services.
     '''
 
-    command = 'systemctl -al list-units'
     requires_command = 'systemctl'
 
     default = dict
@@ -33,6 +48,15 @@ class SystemdStatus(FactBase):
     regex = r'^({systemd_unit_name_regex})\s+[a-z\-]+\s+[a-z]+\s+([a-z]+)'.format(
         systemd_unit_name_regex=SYSTEMD_UNIT_NAME_REGEX)
 
+    def command(self, user_mode=False, machine=None, user_name=None):
+        fact_cmd = _make_systemctl_cmd(
+            user_mode=user_mode,
+            machine=machine,
+            user_name=user_name,
+        )
+
+        return '{0} -al --plain --no-legend list-units'.format(fact_cmd)
+
     def process(self, output):
         services = {}
 
@@ -51,15 +75,6 @@ class SystemdEnabled(FactBase):
     Returns a dict of name -> whether enabled for systemd managed services.
     '''
 
-    command = '''
-        systemctl --no-legend -al list-unit-files | while read -r UNIT STATUS; do
-            if [ "$STATUS" = generated ] &&
-                systemctl is-enabled $UNIT >/dev/null 2>&1; then
-                STATUS=enabled
-            fi
-            echo $UNIT $STATUS
-        done
-    '''
     requires_command = 'systemctl'
 
     default = dict
@@ -67,6 +82,23 @@ class SystemdEnabled(FactBase):
     regex = r'^({systemd_unit_name_regex})\s+([a-z]+)'.format(
         systemd_unit_name_regex=SYSTEMD_UNIT_NAME_REGEX)
 
+    def command(self, user_mode=False, machine=None, user_name=None):
+        fact_cmd = _make_systemctl_cmd(
+            user_mode=user_mode,
+            machine=machine,
+            user_name=user_name,
+        )
+
+        return (
+            '{0} -al --plain --no-legend --state=loaded list-units | '
+            'while read -r UNIT REST; do '
+            'STATE=$({0} -P UnitFileState show -- "$UNIT"); '
+            'if [ -n "$STATE" ]; then '
+            'echo "$UNIT" "$STATE"; '
+            'fi; '
+            'done'
+        ).format(fact_cmd)
+
     def process(self, output):
         units = {}
 
