@@ -145,7 +145,7 @@ class TestOperationsApi(PatchSSHTestCase):
         )
 
     @patch('pyinfra.api.util.open', mock_open(read_data='test!'), create=True)
-    @patch('pyinfra.operations.files.os_path.isfile', lambda *args, **kwargs: True)
+    @patch('pyinfra.operations.files.os.path.isfile', lambda *args, **kwargs: True)
     def test_file_upload_op(self):
         inventory = make_inventory()
 
@@ -224,7 +224,7 @@ class TestOperationsApi(PatchSSHTestCase):
         state = State(inventory, Config())
         connect_all(state)
 
-        with patch('pyinfra.operations.files.os_path.isfile', lambda *args, **kwargs: True):
+        with patch('pyinfra.operations.files.os.path.isfile', lambda *args, **kwargs: True):
             add_op(
                 state, files.get,
                 name='First op name',
